[PATCH 5 of 5] color: add the ability to display configured style to 'debugcolor'

Pierre-Yves David pierre-yves.david at ens-lyon.org
Thu Nov 3 11:56:36 EDT 2016


# HG changeset patch
# User Pierre-Yves David <pierre-yves.david at ens-lyon.org>
# Date 1478182622 -3600
#      Thu Nov 03 15:17:02 2016 +0100
# Node ID cfef7fd6c10c67db982062c4761cdaf11eeaeec2
# Parent  ca827619fe6580c6e9220b0e98c6d9dfc51f6b4f
# EXP-Topic debugcolor
color: add the ability to display configured style to 'debugcolor'

The 'hg debugcolor' command gains a '--style' flag to display all the configured
labels and their styles. This have many benefits:

 * discovering documented label,
 * checking consistency between label's style,
 * showing the actual style of a label.

diff --git a/hgext/color.py b/hgext/color.py
--- a/hgext/color.py
+++ b/hgext/color.py
@@ -536,11 +536,16 @@ def extsetup(ui):
          _("when to colorize (boolean, always, auto, never, or debug)"),
          _('TYPE')))
 
- at command('debugcolor', [], 'hg debugcolor')
+ at command('debugcolor',
+        [('', 'style', None, _('show all configured styles'))],
+        'hg debugcolor')
 def debugcolor(ui, repo, **opts):
     """show available colors and effects"""
     ui.write(('color mode: %s\n') % ui._colormode)
-    return _debugdisplaycolor(ui)
+    if opts.get('style'):
+        return _debugdisplaystyle(ui)
+    else:
+        return _debugdisplaycolor(ui)
 
 def _debugdisplaycolor(ui):
     global _styles
@@ -564,6 +569,18 @@ def _debugdisplaycolor(ui):
     finally:
         _styles = oldstyle
 
+def _debugdisplaystyle(ui):
+    ui.write(_('available style:\n'))
+    width = max(len(s) for s in _styles)
+    for label, effects in sorted(_styles.items()):
+        ui.write('%s' % label, label=label)
+        if effects:
+            # 50
+            ui.write(': ')
+            ui.write(' ' * (max(0, width - len(label))))
+            ui.write(', '.join(ui.label(e, e) for e in effects.split()))
+        ui.write('\n')
+
 if os.name != 'nt':
     w32effects = None
 else:
@@ -536,11 +536,16 @@ def extsetup(ui):
 def debugcolor(ui, repo, **opts):
-    """show available colors and effects"""
+    """show available color, effects or style"""
     ui.write(('color mode: %s\n') % ui._colormode)


More information about the Mercurial-devel mailing list